# syntax = devthefuture/dockerfile-x

# We use the dockerfile-x syntax to demonstrate what would be required from an
# actual application that was using the base Dockerfile. Note that due to the
# docker build's context system this Dockerfile must be build from the parent
# directory, with the command:
#
# $ docker build -f example/Dockerfile .

FROM ./Dockerfile as base

# Copy function code
COPY example ./example
WORKDIR /usr/src/app/example

# Example testing image
FROM base as tox

RUN pip install tox
ENTRYPOINT ["tox"]
CMD []

# Example full image
FROM base as full

# If our function had requirements we could install them now:
# RUN pip install -r requirements.txt
# or, since poetry is available:
# RUN poetry install --no-root

# Set the CMD to execute the ucam-faas main code, with our target function. The
# ENTRYPOINT is already set to 'sh -c'.
CMD ["say_hello", "--debug"]
